@@ -6,4 +6,4 @@ from .oai.ApiManager import ApiManager, SingleApiManager
 
 from .oai.types.base import Message, ResponseDict
 from .oai.types.chat import ChatSequence, ChatConversation, ChatPair
-from .oai.types.functions import FunctionPair, Functions
\ No newline at end of file
+from .oai.types.functions import FunctionPair, Functions, FunctionDef
\ No newline at end of file
